Was this page helpful?
Caution
You're viewing documentation for a previous version of ScyllaDB CPP RS Driver. Switch to the latest stable version.
CassVersion¶
-
struct CassVersion¶
Describes the version of the connected Cassandra cluster.
Caution
You're viewing documentation for a previous version of ScyllaDB CPP RS Driver. Switch to the latest stable version.
Describes the version of the connected Cassandra cluster.
Was this page helpful?